=== added file 'CMakeLists.txt'
--- CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ CMakeLists.txt	2014-01-27 14:50:56 +0000
@@ -0,0 +1,62 @@
+project(com.ubuntu.calendar)
+cmake_minimum_required(VERSION 2.8.9)
+
+# Standard install paths
+include(GNUInstallDirs)
+
+option(INSTALL_TESTS "Install the tests on make install" on)
+option(CLICK_MODE "Installs to a contained location" off)
+
+set(APP_NAME calendar)
+set(DESKTOP_FILE "${PROJECT_NAME}_${APP_NAME}.desktop")
+set(URLS_FILE "${PROJECT_NAME}_${APP_NAME}.url-dispatcher")
+set(MAIN_QML calendar.qml)
+set(ICON calendar64.png)
+set(AUTOPILOT_DIR calendar_app)
+set(APP_HARDCODE calendar-app)
+
+if(CLICK_MODE)
+    if(NOT DEFINED BZR_SOURCE)
+		set(BZR_SOURCE "lp:ubuntu-${APP_HARDCODE}")
+		message("-- Setting BZR_SOURCE to ${BZR_SOURCE}")
+    endif(NOT DEFINED BZR_SOURCE)
+    set(CMAKE_INSTALL_PREFIX /)
+    set(CMAKE_INSTALL_BINDIR /)
+	set(DATA_DIR /)
+	set(EXEC "qmlscene %u ${MAIN_QML}")
+	set(DESKTOP_DIR ${DATA_DIR})
+	set(URLS_DIR ${DATA_DIR})
+else(CLICK_MODE)
+	set(DATA_DIR ${CMAKE_INSTALL_DATADIR}/${APP_HARDCODE})
+	set(EXEC ${APP_HARDCODE})
+	set(ICON ${CMAKE_INSTALL_PREFIX}/${DATA_DIR}/${ICON})
+	configure_file(${APP_HARDCODE}.in
+		${CMAKE_CURRENT_BINARY_DIR}/${APP_HARDCODE})
+	install(PROGRAMS ${CMAKE_CURRENT_BINARY_DIR}/${APP_HARDCODE}
+		DESTINATION ${CMAKE_INSTALL_BINDIR})
+	set(DESKTOP_DIR ${CMAKE_INSTALL_DATADIR}/applications)
+	set(URLS_DIR ${CMAKE_INSTALL_DATADIR}/url-dispatcher/urls)
+endif(CLICK_MODE)
+
+file(GLOB_RECURSE I18N_SRC_FILES
+     RELATIVE ${CMAKE_CURRENT_SOURCE_DIR}
+     rc/**.qml desktop/**.desktop.in)
+list(SORT I18N_SRC_FILES)
+
+
+file(GLOB SRC_FILES
+     RELATIVE ${CMAKE_CURRENT_SOURCE_DIR}
+     *.qml *.js *.png *.js)
+install(FILES ${SRC_FILES}  DESTINATION ${DATA_DIR})
+
+configure_file(${DESKTOP_FILE}.in ${CMAKE_CURRENT_BINARY_DIR}/${DESKTOP_FILE})
+install(FILES ${CMAKE_CURRENT_BINARY_DIR}/${DESKTOP_FILE} DESTINATION ${DESKTOP_DIR})
+ 
+install(FILES ${URLS_FILE} DESTINATION ${URLS_DIR})
+
+# Tests
+enable_testing()
+
+add_subdirectory(click)
+add_subdirectory(po)
+add_subdirectory(tests)

=== modified file 'DayView.qml'
--- DayView.qml	2013-10-16 14:36:51 +0000
+++ DayView.qml	2014-01-28 01:51:29 +0000
@@ -7,8 +7,6 @@
     id: root
     objectName: "DayView"
 
-    anchors.fill: parent
-
     property var currentDay: new Date()
 
     Column {
@@ -18,6 +16,8 @@
         width: parent.width; height: parent.height
         spacing: units.gu(1)
 
+        anchors.fill: parent
+
         ViewHeader{
             id: viewHeader
             date: currentDay
@@ -47,7 +47,7 @@
             preferredHighlightEnd: 0.5
 
             width: parent.width
-            height: column.height - viewHeader.height - dayHeader.height
+            height: column.height - dayViewPath.y
 
             path: Path {
                 startX: -(dayViewPath.width/1.75); startY: dayViewPath.height/2

=== modified file 'EventDetails.qml'
--- EventDetails.qml	2013-10-15 23:52:44 +0000
+++ EventDetails.qml	2014-01-18 03:15:28 +0000
@@ -4,6 +4,8 @@
 import Ubuntu.Components.ListItems 0.1
 import Ubuntu.Components.Themes.Ambiance 0.1
 
+import "GlobalEventModel.js" as GlobalModel
+
 Page {
     id: root
 
@@ -21,7 +23,15 @@
         if( pageStack.header )
             pageStack.header.visible = true;
     }
-
+    Connections{
+        target: pageStack
+        onCurrentPageChanged:{
+            if( pageStack.currentPage === root) {
+                pageStack.header.visible = false;
+                showEvent(event);
+            }
+        }
+    }
     function showEvent(e) {
         var location = "";
 
@@ -31,10 +41,10 @@
         var startTime = e.startDateTime.toLocaleTimeString(Qt.locale(), timeFormat);
         var endTime = e.endDateTime.toLocaleTimeString(Qt.locale(), timeFormat);
 
-	startHeader.value = startTime;
-	endHeader.value = endTime;
+        startHeader.value = startTime;
+        endHeader.value = endTime;
 
-	// This is the event title
+        // This is the event title
         if( e.displayLabel) {
             titleLabel.text = e.displayLabel;
         }
@@ -51,7 +61,6 @@
             for( var j = 0 ; j < attendees.length ; ++j ) {
                 contactModel.append( {"name": attendees[j].name } );
             }
-
         }
         // FIXME: need to cache map image to avoid duplicate download every time
         var imageSrc = "http://maps.googleapis.com/maps/api/staticmap?center="+location+
@@ -62,28 +71,29 @@
 
     tools: ToolbarItems {
 
-	/*
         ToolbarButton {
-            action: Action {
-                text: i18n.tr("Add invite");
+            action:Action {
+                text: i18n.tr("Delete");
+                iconSource: "image://theme/delete,edit-delete-symbolic"
                 onTriggered: {
-                    print(text + " not implemented");
+                    var eventModel = GlobalModel.gloablModel();
+                    eventModel.removeItem(event);
+                    pageStack.pop();
                 }
             }
         }
-	*/
-	/*
+
         ToolbarButton {
             action:Action {
                 text: i18n.tr("Edit");
                 iconSource: Qt.resolvedUrl("edit.svg");
                 onTriggered: {
-                    print(text + " not implemented");
+                   pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"event":event});
                 }
             }
         }
-	*/
     }
+
     Rectangle {
         id:eventDetilsView
         anchors.fill: parent

=== modified file 'EventListModel.qml'
--- EventListModel.qml	2013-09-28 03:20:54 +0000
+++ EventListModel.qml	2013-10-17 12:52:23 +0000
@@ -3,14 +3,13 @@
 
 import QtOrganizer 5.0
 
-//http://qt.gitorious.org/qt/qtpim/blobs/master/examples/organizer/qmlorganizerlistview/qmlorganizerlistview.qml
 OrganizerModel {
     id: eventModel
     manager:"eds"
 
     signal reloaded
 
-    onItemCountChanged:{
+    onModelChanged: {
         reloaded();
     }
 }

=== modified file 'MonthComponent.qml'
--- MonthComponent.qml	2013-11-27 13:24:56 +0000
+++ MonthComponent.qml	2014-01-11 05:59:53 +0000
@@ -98,7 +98,7 @@
             height: parent.height / parent.weekCount
 
             Loader {
-                width: parent.width
+                width: parent.width < parent.height ? parent.width : parent.height
                 height: width
                 anchors.centerIn: parent
                 sourceComponent: date.isSameDay(DateExt.today()) && isCurrentMonth ? highLightComp : undefined

=== modified file 'MonthView.qml'
--- MonthView.qml	2014-01-31 01:09:36 +0000
+++ MonthView.qml	2014-01-31 01:35:20 +0000
@@ -5,6 +5,7 @@
 
 Page {
     id: monthViewPage
+    objectName: "MonthView"
 
     property var currentMonth: DateExt.today();
 

=== modified file 'NewEvent.qml'
--- NewEvent.qml	2013-10-31 15:09:14 +0000
+++ NewEvent.qml	2014-01-01 04:22:40 +0000
@@ -8,15 +8,21 @@
 
 Page {
     id: root
-
     property var date: new Date();
+
+    property var event:null;
+
     property var startDate;
     property var endDate;
     property int optionSelectorWidth: frequencyLabel.width > remindLabel.width ? frequencyLabel.width : remindLabel.width
 
     property alias scrollY: flickable.contentY
+    property bool isEdit: false
 
     Component.onCompleted: {
+
+        pageStack.header.visible = true;
+
         // If startDate is setted by argument we have to not change it
         if (typeof(startDate) === 'undefined')
             startDate = new Date(date)
@@ -26,37 +32,65 @@
             endDate = new Date(date)
             endDate.setMinutes( endDate.getMinutes() + 10)
         }
-
         internal.eventModel = GlobalModel.gloablModel();
 
+        if(event === null){
+            isEdit =false;
+            addEvent();
+        }
+        else{
+            isEdit = true;
+            editEvent(event);
+        }
+    }
+    //Data for Add events
+    function addEvent() {
+        event = Qt.createQmlObject("import QtOrganizer 5.0; Event { }", Qt.application,"NewEvent.qml");
+        startDate = new Date(date)
+        endDate = new Date(date)
+        endDate.setMinutes( endDate.getMinutes() + 10)
+
         startTime.text = Qt.formatDateTime(startDate, "dd MMM yyyy hh:mm");
         endTime.text = Qt.formatDateTime(endDate, "dd MMM yyyy hh:mm");
     }
-
+    //Editing Event
+    function editEvent(e) {
+        startDate =new Date(e.startDateTime);
+        endDate = new Date(e.endDateTime);
+        startTime.text = Qt.formatDateTime(e.startDateTime, "dd MMM yyyy hh:mm");
+        endTime.text = Qt.formatDateTime(e.endDateTime, "dd MMM yyyy hh:mm");
+        if(e.displayLabel)
+            titleEdit.text = e.displayLabel;
+        if(e.location)
+            locationEdit.text = e.location;
+        if( e.description ) {
+            messageEdit.text = e.description;
+        }
+        if(e.attendees){
+            for( var j = 0 ; j < e.attendees.length ; ++j ) {
+                personEdit.text += e.attendees[j].name;
+                if(j!== e.attendees.length-1)
+                    personEdit.text += ",";
+            }
+        }
+    }
+    //Save the new or Existing event
     function saveToQtPim() {
-
         internal.clearFocus()
-
         if ( startDate >= endDate ) {
             PopupUtils.open(errorDlgComponent,root,{"text":i18n.tr("End time can't be before start time")});
         } else {
-
-            var event = Qt.createQmlObject("import QtOrganizer 5.0; Event { }", Qt.application,"NewEvent.qml");
-
             event.startDateTime = startDate;
             event.endDateTime = endDate;
             event.displayLabel = titleEdit.text;
             event.description = messageEdit.text;
-
             event.location = locationEdit.text
-
+            event.attendees = []; // if Edit remove all attendes & add them again if any
             if( personEdit.text != "") {
                 var attendee = Qt.createQmlObject("import QtOrganizer 5.0; EventAttendee{}", Qt.application, "NewEvent.qml");
                 attendee.name = personEdit.text;
-                attendee.emailAddress = "none@nowhere.com";
                 event.setDetail(attendee);
             }
-
             internal.eventModel.saveItem(event);
             pageStack.pop();
         }
@@ -65,7 +99,7 @@
     width: parent.width
     height: parent.height
 
-    title: i18n.tr("New Event")
+    title: isEdit ? i18n.tr("Edit Event"):i18n.tr("New Event")
 
     tools: ToolbarItems {
         //keeping toolbar always open
@@ -107,7 +141,6 @@
             }
         }
     }
-
     Component {
         id: timePicker
         TimePicker {
@@ -194,7 +227,6 @@
                     }
                 }
             }
-
             NewEventEntryField{
                 id: titleEdit
                 width: parent.width

=== modified file 'TimeLineBase.qml'
--- TimeLineBase.qml	2013-09-28 03:37:02 +0000
+++ TimeLineBase.qml	2014-01-18 03:11:01 +0000
@@ -65,6 +65,7 @@
             if( children[i].objectName === "separator") {
                 children[i].visible = false;
             } else {
+                children[i].visible = false;
                 children[i].destroy();
             }
         }

=== modified file 'WeekView.qml'
--- WeekView.qml	2013-12-14 02:44:09 +0000
+++ WeekView.qml	2014-01-31 01:35:20 +0000
@@ -5,6 +5,7 @@
 
 Column {
     id: root
+    objectName: "WeekView"
 
     property var dayStart: new Date();
     property var firstDay: dayStart.weekStart(Qt.locale().firstDayOfWeek);
@@ -33,7 +34,7 @@
         property var weekStart: weekViewPath.visibleWeek
 
         width: parent.width
-        height: root.height - viewHeader.height - weekHeader.height
+        height: root.height - weekViewPath.y
 
         onNextItemHighlighted: {
             nextWeek();

=== modified file 'YearView.qml'
--- YearView.qml	2014-01-31 01:02:27 +0000
+++ YearView.qml	2014-01-31 01:35:20 +0000
@@ -5,6 +5,7 @@
 
 PathViewBase {
     id: root
+    objectName: "YearView"
 
     property var currentYear: DateExt.today();
 

=== removed directory 'apparmor'
=== renamed file 'calendar-app' => 'calendar-app.in' (properties changed: +x to -x)
--- calendar-app	2013-06-12 15:23:13 +0000
+++ calendar-app.in	2014-01-18 23:29:11 +0000
@@ -1,2 +1,3 @@
-#!/bin/bash
-qmlscene /usr/share/calendar-app/calendar.qml
+#!/bin/sh
+export QT_SELECT=qt5
+qmlscene @CMAKE_INSTALL_PREFIX@/@DATA_DIR@/@MAIN_QML@

=== modified file 'calendar.qml'
--- calendar.qml	2013-10-29 20:55:31 +0000
+++ calendar.qml	2014-01-09 23:15:57 +0000
@@ -179,8 +179,8 @@
                         }
                     } // End of else if (starttime)
                     else {
-                    	// Due to bug #1231558 {if (args.defaultArgument.at(0))} is always true
-                    	// After the fix we can delete this else
+                        // Due to bug #1231558 {if (args.defaultArgument.at(0))} is always true
+                        // After the fix we can delete this else
                         tabs.selectedTabIndex= 1;
                     }
                 } // End of if about args.values
@@ -253,6 +253,7 @@
                 }
                 Tab {
                     id: monthTab
+                    objectName: "monthTab"
                     title: i18n.tr("Month")
                     page: MonthView{
                         anchors.fill: parent

=== added directory 'click'
=== added file 'click/CMakeLists.txt'
--- click/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ click/CMakeLists.txt	2014-01-18 23:29:11 +0000
@@ -0,0 +1,8 @@
+if(CLICK_MODE)
+    if(NOT BZR_REVNO)
+        set(BZR_REVNO "latest")
+    endif(NOT BZR_REVNO)
+    configure_file(manifest.json.in ${CMAKE_CURRENT_BINARY_DIR}/manifest.json)
+    install(FILES ${CMAKE_CURRENT_BINARY_DIR}/manifest.json apparmor.json
+            DESTINATION ${CMAKE_INSTALL_PREFIX})
+endif(CLICK_MODE)

=== renamed file 'apparmor/calendar.json' => 'click/apparmor.json'
=== renamed file 'manifest.json' => 'click/manifest.json.in'
--- manifest.json	2013-10-16 13:23:39 +0000
+++ click/manifest.json.in	2014-01-27 22:39:34 +0000
@@ -2,14 +2,22 @@
     "description": "Calendar application for Ubuntu devices",
     "framework": "ubuntu-sdk-13.10",
     "hooks": {
-        "calendar": {
-            "apparmor": "apparmor/calendar.json",
-            "desktop": "calendar-app.desktop"
+        "@APP_NAME@": {
+            "apparmor": "apparmor.json",
+            "desktop": "@DESKTOP_FILE@",
+            "urls": "@URLS_FILE@"
         }
     },
-    "icon": "calendar64.png",
+    "icon": "@ICON@",
     "maintainer": "Ubuntu App Cats <ubuntu-touch-coreapps@lists.launchpad.net>",
-    "name": "com.ubuntu.calendar",
-    "title": "calendar",
-    "version": "0.4"
+    "name": "@PROJECT_NAME@",
+    "title": "Calendar",
+    "version": "0.4.@BZR_REVNO@",
+    "x-source": {
+        "vcs-bzr": "@BZR_SOURCE@", 
+        "vcs-bzr-revno": "@BZR_REVNO@"
+    },
+	"x-test": {
+		"autopilot": "@AUTOPILOT_DIR@"
+	}
 }

=== renamed file 'calendar-app.desktop' => 'com.ubuntu.calendar_calendar.desktop.in'
--- calendar-app.desktop	2013-10-16 18:43:17 +0000
+++ com.ubuntu.calendar_calendar.desktop.in	2014-01-18 23:29:11 +0000
@@ -2,9 +2,9 @@
 Version=1.0
 Type=Application
 Terminal=false
-Exec=qmlscene %u /usr/share/calendar-app/calendar.qml
-Icon=/usr/share/calendar-app/calendar64.png
+Exec=@EXEC@
+Icon=@ICON@
 Name=Calendar
 X-Ubuntu-Touch=true
 X-Ubuntu-StageHint=SideStage
-X-Ubuntu-Gettext-Domain=com.ubuntu.calendar
+X-Ubuntu-Gettext-Domain=@PROJECT_NAME@

=== added file 'com.ubuntu.calendar_calendar.url-dispatcher'
--- com.ubuntu.calendar_calendar.url-dispatcher	1970-01-01 00:00:00 +0000
+++ com.ubuntu.calendar_calendar.url-dispatcher	2014-01-27 14:50:56 +0000
@@ -0,0 +1,5 @@
+[
+	{
+		"protocol": "calendar"
+	}
+]

=== modified file 'debian/calendar-app-autopilot.install'
--- debian/calendar-app-autopilot.install	2013-06-12 15:47:15 +0000
+++ debian/calendar-app-autopilot.install	2014-01-18 23:29:11 +0000
@@ -1,1 +1,2 @@
-tests/autopilot/calendar_app/* usr/lib/python2.7/dist-packages/calendar_app/
+usr/lib/*/dist-packages/calendar_app/*
+

=== modified file 'debian/calendar-app.install'
--- debian/calendar-app.install	2013-06-12 15:23:13 +0000
+++ debian/calendar-app.install	2014-01-18 23:29:11 +0000
@@ -1,5 +1,2 @@
-calendar-app usr/bin/
-calendar-app.desktop usr/share/applications/
-*.qml usr/share/calendar-app/
-*.png usr/share/calendar-app/
-*.js usr/share/calendar-app/
+usr/bin/*
+usr/share/*

=== modified file 'debian/changelog'
--- debian/changelog	2013-06-12 15:32:14 +0000
+++ debian/changelog	2014-01-18 23:29:11 +0000
@@ -1,3 +1,9 @@
+calendar-app (0.4ubuntu1) UNRELEASED; urgency=medium
+
+  * Adding cmake 
+
+ -- Sergio Schvezov <sergio.schvezov@canonical.com>  Sat, 18 Jan 2014 17:05:03 -0300
+
 calendar-app (0.4) raring; urgency=low
 
   * Renamed package

=== modified file 'debian/control'
--- debian/control	2013-10-25 04:07:59 +0000
+++ debian/control	2014-01-28 16:48:59 +0000
@@ -1,7 +1,9 @@
 Source: calendar-app
 Priority: extra
 Maintainer: Ubuntu App Cats <ubuntu-touch-coreapps@lists.launchpad.net>
-Build-Depends: debhelper (>= 9), 
+Build-Depends: cmake,
+               debhelper (>= 9),
+               python,
                qtdeclarative5-dev-tools,
                qt5-default,
                qtdeclarative5-qtquick2-plugin,

=== modified file 'debian/rules'
--- debian/rules	2013-10-16 18:43:17 +0000
+++ debian/rules	2014-01-28 16:20:21 +0000
@@ -6,19 +6,3 @@
 
 %:
 	dh $@
-
-override_dh_auto_test:
-	QT_QPA_PLATFORM=minimal qmltestrunner -input tests/unittests/
-
-override_dh_install:
-	dh_install --fail-missing
-	appname=com.ubuntu.calendar; \
-	for pofile in $(shell find ./po -name "*.po"); do \
-		pofilename="$${pofile##*/}"; \
-		langcode="$${pofilename%.*}"; \
-		localedir="usr/share/locale/$$langcode/LC_MESSAGES"; \
-		mofile="$$appname.mo"; \
-		msgfmt -o $$mofile $$pofile; \
-		dh_install $$mofile $$localedir; \
-		rm -f $$mofile; \
-	done

=== added file 'po/CMakeLists.txt'
--- po/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ po/CMakeLists.txt	2014-01-18 23:29:11 +0000
@@ -0,0 +1,25 @@
+include(FindGettext)
+find_program(GETTEXT_XGETTEXT_EXECUTABLE xgettext)
+
+set(DOMAIN ${PROJECT_NAME})
+set(POT_FILE ${DOMAIN}.pot)
+file(GLOB PO_FILES *.po)
+
+add_custom_target(${POT_FILE}
+                  COMMAND ${GETTEXT_XGETTEXT_EXECUTABLE} -o ${POT_FILE}
+                          -D ${CMAKE_SOURCE_DIR}
+                          --from-code=UTF-8
+                          --c++ --qt --add-comments=TRANSLATORS
+                          --keyword=tr --keyword=tr:1,2
+						  --package-name='${PROJECT}'
+                          --copyright-holder='Canonical Ltd.'
+                          ${I18N_SRC_FILES})
+
+foreach(PO_FILE ${PO_FILES})
+    get_filename_component(LANG ${PO_FILE} NAME_WE)
+    gettext_process_po_files(${LANG} ALL PO_FILES ${PO_FILE})
+    set(INSTALL_DIR ${CMAKE_INSTALL_LOCALEDIR}/${LANG}/LC_MESSAGES)
+    install(FILES ${CMAKE_CURRENT_BINARY_DIR}/${LANG}.gmo
+            DESTINATION ${INSTALL_DIR}
+            RENAME ${DOMAIN}.mo)
+endforeach(PO_FILE)

=== modified file 'po/ast.po'
--- po/ast.po	2013-12-03 06:16:42 +0000
+++ po/ast.po	2014-01-15 06:22:22 +0000
@@ -8,14 +8,14 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2013-09-26 07:05+0200\n"
-"PO-Revision-Date: 2013-10-03 10:34+0000\n"
-"Last-Translator: ivarela <ivarela@ubuntu.com>\n"
+"PO-Revision-Date: 2014-01-14 20:54+0000\n"
+"Last-Translator: Xuacu Saturio <xuacusk8@gmail.com>\n"
 "Language-Team: Asturian <ast@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-01-15 06:22+0000\n"
+"X-Generator: Launchpad (build 16890)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
@@ -32,7 +32,7 @@
 
 #: ../EventDetails.qml:70
 msgid "Add invite"
-msgstr ""
+msgstr "Amestar invitación"
 
 #: ../EventDetails.qml:79
 msgid "Edit"
@@ -64,70 +64,70 @@
 
 #: ../NewEvent.qml:156
 msgid "Invite People"
-msgstr ""
+msgstr "Invitar xente"
 
 #: ../NewEvent.qml:168
 msgid "Error"
-msgstr ""
+msgstr "Error"
 
 #: ../NewEvent.qml:171 ../TimePicker.qml:82
 msgid "OK"
-msgstr ""
+msgstr "Aceutar"
 
 #: ../NewEvent.qml:177
 msgid "Save"
-msgstr ""
+msgstr "Guardar"
 
 #: ../NewEvent.qml:205
 msgid "End time can't be before start time"
-msgstr ""
+msgstr "El tiempu final nun pue ser anterior al d'aniciu"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
 msgid "hh ap"
-msgstr ""
+msgstr "hh ap"
 
 #: ../TimePicker.qml:23
 msgid "Time"
-msgstr ""
+msgstr "Tiempu"
 
 #: ../TimePicker.qml:49
 msgid "Hour"
-msgstr ""
+msgstr "Hora"
 
 #: ../TimePicker.qml:63
 msgid "Minute"
-msgstr ""
+msgstr "Minutu"
 
 #: ../TimePicker.qml:73
 msgid "Cancel"
-msgstr ""
+msgstr "Encaboxar"
 
 #: ../calendar.qml:56
 msgid "New Event"
-msgstr ""
+msgstr "Nueva actividá"
 
 #: ../calendar.qml:64
 msgid "Today"
-msgstr ""
+msgstr "Güei"
 
 #: ../calendar.qml:75
 msgid "Year"
-msgstr ""
+msgstr "Añu"
 
 #: ../calendar.qml:95
 msgid "Month"
-msgstr ""
+msgstr "Mes"
 
 #: ../calendar.qml:108
 msgid "Week"
-msgstr ""
+msgstr "Selmana"
 
 #: ../calendar.qml:124
 msgid "Day"
-msgstr ""
+msgstr "Día"
 
 #: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
-msgstr ""
+msgstr "Calendariu"

=== modified file 'po/bg.po'
--- po/bg.po	2013-12-03 06:16:42 +0000
+++ po/bg.po	2014-01-26 05:15:56 +0000
@@ -8,126 +8,126 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2013-09-26 07:05+0200\n"
-"PO-Revision-Date: 2013-10-20 15:41+0000\n"
-"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
+"PO-Revision-Date: 2014-01-25 16:34+0000\n"
+"Last-Translator: Gangov <Unknown>\n"
 "Language-Team: Bulgarian <bg@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-01-26 05:15+0000\n"
+"X-Generator: Launchpad (build 16914)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../EventBubble.qml:38
 msgid "hh:mm"
-msgstr ""
+msgstr "чч:мм"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
 #: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
-msgstr ""
+msgstr "%1 - %2"
 
 #: ../EventDetails.qml:70
 msgid "Add invite"
-msgstr ""
+msgstr "Добави покана"
 
 #: ../EventDetails.qml:79
 msgid "Edit"
-msgstr ""
+msgstr "Редактиране"
 
 #: ../EventDetails.qml:153
 msgid "People"
-msgstr ""
+msgstr "Хора"
 
 #: ../NewEvent.qml:23
 msgid "Create event"
-msgstr ""
+msgstr "Създай събитие"
 
 #: ../NewEvent.qml:29
 msgid "Add event name"
-msgstr ""
+msgstr "Добави име на събитието"
 
 #: ../NewEvent.qml:102
 msgid "to"
-msgstr ""
+msgstr "до"
 
 #: ../NewEvent.qml:137
 msgid "Location & People"
-msgstr ""
+msgstr "Местоположение и хора"
 
 #: ../NewEvent.qml:143
 msgid "Add Location"
-msgstr ""
+msgstr "Добавяне на местоположение"
 
 #: ../NewEvent.qml:156
 msgid "Invite People"
-msgstr ""
+msgstr "Покани хора"
 
 #: ../NewEvent.qml:168
 msgid "Error"
-msgstr ""
+msgstr "Грешка"
 
 #: ../NewEvent.qml:171 ../TimePicker.qml:82
 msgid "OK"
-msgstr ""
+msgstr "ОК"
 
 #: ../NewEvent.qml:177
 msgid "Save"
-msgstr ""
+msgstr "Запазване"
 
 #: ../NewEvent.qml:205
 msgid "End time can't be before start time"
-msgstr ""
+msgstr "Времето за край не може да бъде преди времето за начало"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
 msgid "hh ap"
-msgstr ""
+msgstr "чч ап"
 
 #: ../TimePicker.qml:23
 msgid "Time"
-msgstr ""
+msgstr "Време"
 
 #: ../TimePicker.qml:49
 msgid "Hour"
-msgstr ""
+msgstr "Час"
 
 #: ../TimePicker.qml:63
 msgid "Minute"
-msgstr ""
+msgstr "Минута"
 
 #: ../TimePicker.qml:73
 msgid "Cancel"
-msgstr ""
+msgstr "Отмени"
 
 #: ../calendar.qml:56
 msgid "New Event"
-msgstr ""
+msgstr "Ново събитие"
 
 #: ../calendar.qml:64
 msgid "Today"
-msgstr ""
+msgstr "Днес"
 
 #: ../calendar.qml:75
 msgid "Year"
-msgstr ""
+msgstr "Година"
 
 #: ../calendar.qml:95
 msgid "Month"
-msgstr ""
+msgstr "Месец"
 
 #: ../calendar.qml:108
 msgid "Week"
-msgstr ""
+msgstr "Седмица"
 
 #: ../calendar.qml:124
 msgid "Day"
-msgstr ""
+msgstr "Ден"
 
 #: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"
-msgstr ""
+msgstr "Календар"

=== modified file 'po/cs.po'
--- po/cs.po	2013-12-03 06:16:42 +0000
+++ po/cs.po	2014-01-08 05:40:50 +0000
@@ -8,31 +8,31 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2013-09-26 07:05+0200\n"
-"PO-Revision-Date: 2013-09-16 18:19+0000\n"
-"Last-Translator: Ondra Kadlec <o.kadlec@seznam.cz>\n"
+"PO-Revision-Date: 2014-01-07 09:08+0000\n"
+"Last-Translator: Tadeáš Pařík <tadeas.parik@gmail.com>\n"
 "Language-Team: Czech <cs@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-01-08 05:40+0000\n"
+"X-Generator: Launchpad (build 16877)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../EventBubble.qml:38
 msgid "hh:mm"
-msgstr ""
+msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
 #: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
-msgstr ""
+msgstr "%1 - %2"
 
 #: ../EventDetails.qml:70
 msgid "Add invite"
-msgstr ""
+msgstr "Přidat pozvánku"
 
 #: ../EventDetails.qml:79
 msgid "Edit"
@@ -52,11 +52,11 @@
 
 #: ../NewEvent.qml:102
 msgid "to"
-msgstr ""
+msgstr "Pro"
 
 #: ../NewEvent.qml:137
 msgid "Location & People"
-msgstr ""
+msgstr "Umístění & lidé"
 
 #: ../NewEvent.qml:143
 msgid "Add Location"
@@ -68,11 +68,11 @@
 
 #: ../NewEvent.qml:168
 msgid "Error"
-msgstr ""
+msgstr "Chyba"
 
 #: ../NewEvent.qml:171 ../TimePicker.qml:82
 msgid "OK"
-msgstr ""
+msgstr "OK"
 
 #: ../NewEvent.qml:177
 msgid "Save"
@@ -80,29 +80,29 @@
 
 #: ../NewEvent.qml:205
 msgid "End time can't be before start time"
-msgstr ""
+msgstr "Čas ukončení nemůže být před začátkem události"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
 msgid "hh ap"
-msgstr ""
+msgstr "hh ap"
 
 #: ../TimePicker.qml:23
 msgid "Time"
-msgstr ""
+msgstr "Čas"
 
 #: ../TimePicker.qml:49
 msgid "Hour"
-msgstr ""
+msgstr "Hodina"
 
 #: ../TimePicker.qml:63
 msgid "Minute"
-msgstr ""
+msgstr "Minuta"
 
 #: ../TimePicker.qml:73
 msgid "Cancel"
-msgstr ""
+msgstr "Zrušit"
 
 #: ../calendar.qml:56
 msgid "New Event"
@@ -110,23 +110,23 @@
 
 #: ../calendar.qml:64
 msgid "Today"
-msgstr ""
+msgstr "Dnes"
 
 #: ../calendar.qml:75
 msgid "Year"
-msgstr ""
+msgstr "Rok"
 
 #: ../calendar.qml:95
 msgid "Month"
-msgstr ""
+msgstr "Měsíc"
 
 #: ../calendar.qml:108
 msgid "Week"
-msgstr ""
+msgstr "Týden"
 
 #: ../calendar.qml:124
 msgid "Day"
-msgstr ""
+msgstr "Den"
 
 #: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"

=== modified file 'po/es.po'
--- po/es.po	2013-12-03 06:16:42 +0000
+++ po/es.po	2014-01-15 06:22:22 +0000
@@ -8,14 +8,14 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2013-09-26 07:05+0200\n"
-"PO-Revision-Date: 2013-10-18 10:46+0000\n"
-"Last-Translator: Jorge Luis Granda <costeelation@hotmail.com>\n"
+"PO-Revision-Date: 2014-01-14 19:25+0000\n"
+"Last-Translator: Jose Luis Tirado <Unknown>\n"
 "Language-Team: Spanish <es@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-01-15 06:22+0000\n"
+"X-Generator: Launchpad (build 16890)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
@@ -52,7 +52,7 @@
 
 #: ../NewEvent.qml:102
 msgid "to"
-msgstr "a"
+msgstr "hasta"
 
 #: ../NewEvent.qml:137
 msgid "Location & People"

=== modified file 'po/hu.po'
--- po/hu.po	2013-12-03 06:16:42 +0000
+++ po/hu.po	2014-01-06 05:05:30 +0000
@@ -8,27 +8,27 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2013-09-26 07:05+0200\n"
-"PO-Revision-Date: 2013-06-16 22:56+0000\n"
-"Last-Translator: Bence Lukács <Unknown>\n"
+"PO-Revision-Date: 2014-01-05 00:55+0000\n"
+"Last-Translator: Mátó Péter <Unknown>\n"
 "Language-Team: Hungarian <hu@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-01-06 05:05+0000\n"
+"X-Generator: Launchpad (build 16877)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../EventBubble.qml:38
 msgid "hh:mm"
-msgstr ""
+msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
 #: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
-msgstr ""
+msgstr "%1 - %2"
 
 #: ../EventDetails.qml:70
 msgid "Add invite"
@@ -52,11 +52,11 @@
 
 #: ../NewEvent.qml:102
 msgid "to"
-msgstr ""
+msgstr "eddig:"
 
 #: ../NewEvent.qml:137
 msgid "Location & People"
-msgstr ""
+msgstr "Hely és személyek"
 
 #: ../NewEvent.qml:143
 msgid "Add Location"
@@ -68,11 +68,11 @@
 
 #: ../NewEvent.qml:168
 msgid "Error"
-msgstr ""
+msgstr "Hiba"
 
 #: ../NewEvent.qml:171 ../TimePicker.qml:82
 msgid "OK"
-msgstr ""
+msgstr "OK"
 
 #: ../NewEvent.qml:177
 msgid "Save"
@@ -80,29 +80,29 @@
 
 #: ../NewEvent.qml:205
 msgid "End time can't be before start time"
-msgstr ""
+msgstr "A végződés időpontjának a kezdés után kell lennie."
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
 msgid "hh ap"
-msgstr ""
+msgstr "hh ap"
 
 #: ../TimePicker.qml:23
 msgid "Time"
-msgstr ""
+msgstr "Idő"
 
 #: ../TimePicker.qml:49
 msgid "Hour"
-msgstr ""
+msgstr "Óra"
 
 #: ../TimePicker.qml:63
 msgid "Minute"
-msgstr ""
+msgstr "Perc"
 
 #: ../TimePicker.qml:73
 msgid "Cancel"
-msgstr ""
+msgstr "Mégse"
 
 #: ../calendar.qml:56
 msgid "New Event"
@@ -110,23 +110,23 @@
 
 #: ../calendar.qml:64
 msgid "Today"
-msgstr ""
+msgstr "Ma"
 
 #: ../calendar.qml:75
 msgid "Year"
-msgstr ""
+msgstr "Év"
 
 #: ../calendar.qml:95
 msgid "Month"
-msgstr ""
+msgstr "Hónap"
 
 #: ../calendar.qml:108
 msgid "Week"
-msgstr ""
+msgstr "Hét"
 
 #: ../calendar.qml:124
 msgid "Day"
-msgstr ""
+msgstr "Nap"
 
 #: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"

=== added file 'po/ja.po'
--- po/ja.po	1970-01-01 00:00:00 +0000
+++ po/ja.po	2014-01-19 05:59:41 +0000
@@ -0,0 +1,133 @@
+# Japanese translation for ubuntu-calendar-app
+# Copyright (c) 2014 Rosetta Contributors and Canonical Ltd 2014
+# This file is distributed under the same license as the ubuntu-calendar-app package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2014.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: ubuntu-calendar-app\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-01-18 14:44+0000\n"
+"Last-Translator: Shushi Kurose <md81bird@hitaki.net>\n"
+"Language-Team: Japanese <ja@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2014-01-19 05:59+0000\n"
+"X-Generator: Launchpad (build 16901)\n"
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../EventBubble.qml:38
+msgid "hh:mm"
+msgstr "hh:mm"
+
+#. TRANSLATORS: the first argument (%1) refers to a start time for an event,
+#. while the second one (%2) refers to the end time
+#: ../EventBubble.qml:43
+#, qt-format
+msgid "%1 - %2"
+msgstr "%1 - %2"
+
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr ""
+
+#: ../EventDetails.qml:79
+msgid "Edit"
+msgstr "編集"
+
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "予定を作成する"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "場所の追加"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "OK"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "保存"
+
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
+msgstr ""
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../TimeLineBackground.qml:18
+msgid "hh ap"
+msgstr ""
+
+#: ../TimePicker.qml:23
+msgid "Time"
+msgstr "時刻"
+
+#: ../TimePicker.qml:49
+msgid "Hour"
+msgstr "時"
+
+#: ../TimePicker.qml:63
+msgid "Minute"
+msgstr "分"
+
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "キャンセル"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "新しいイベント"
+
+#: ../calendar.qml:64
+msgid "Today"
+msgstr ""
+
+#: ../calendar.qml:75
+msgid "Year"
+msgstr "年"
+
+#: ../calendar.qml:95
+msgid "Month"
+msgstr "月"
+
+#: ../calendar.qml:108
+msgid "Week"
+msgstr "週"
+
+#: ../calendar.qml:124
+msgid "Day"
+msgstr "日"
+
+#: ../.build/calendar-app.desktop.js:1
+msgid "Calendar"
+msgstr "カレンダー"

=== added file 'po/pt.po'
--- po/pt.po	1970-01-01 00:00:00 +0000
+++ po/pt.po	2014-01-15 06:22:22 +0000
@@ -0,0 +1,133 @@
+# Portuguese translation for ubuntu-calendar-app
+# Copyright (c) 2014 Rosetta Contributors and Canonical Ltd 2014
+# This file is distributed under the same license as the ubuntu-calendar-app package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2014.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: ubuntu-calendar-app\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-01-14 20:49+0000\n"
+"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
+"Language-Team: Portuguese <pt@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2014-01-15 06:22+0000\n"
+"X-Generator: Launchpad (build 16890)\n"
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../EventBubble.qml:38
+msgid "hh:mm"
+msgstr ""
+
+#. TRANSLATORS: the first argument (%1) refers to a start time for an event,
+#. while the second one (%2) refers to the end time
+#: ../EventBubble.qml:43
+#, qt-format
+msgid "%1 - %2"
+msgstr ""
+
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr ""
+
+#: ../EventDetails.qml:79
+msgid "Edit"
+msgstr ""
+
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
+msgstr ""
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../TimeLineBackground.qml:18
+msgid "hh ap"
+msgstr ""
+
+#: ../TimePicker.qml:23
+msgid "Time"
+msgstr ""
+
+#: ../TimePicker.qml:49
+msgid "Hour"
+msgstr ""
+
+#: ../TimePicker.qml:63
+msgid "Minute"
+msgstr ""
+
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
+msgid "Today"
+msgstr ""
+
+#: ../calendar.qml:75
+msgid "Year"
+msgstr ""
+
+#: ../calendar.qml:95
+msgid "Month"
+msgstr ""
+
+#: ../calendar.qml:108
+msgid "Week"
+msgstr ""
+
+#: ../calendar.qml:124
+msgid "Day"
+msgstr ""
+
+#: ../.build/calendar-app.desktop.js:1
+msgid "Calendar"
+msgstr ""

=== added file 'tests/CMakeLists.txt'
--- tests/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/CMakeLists.txt	2014-01-28 15:57:14 +0000
@@ -0,0 +1,2 @@
+add_subdirectory(autopilot)
+add_subdirectory(unittests)

=== added file 'tests/autopilot/CMakeLists.txt'
--- tests/autopilot/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/autopilot/CMakeLists.txt	2014-01-18 23:29:11 +0000
@@ -0,0 +1,8 @@
+if(INSTALL_TESTS)
+execute_process(COMMAND python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()"
+    OUTPUT_VARIABLE PYTHON_PACKAGE_DIR OUTPUT_STRIP_TRAILING_WHITESPACE)
+
+install(DIRECTORY ${AUTOPILOT_DIR}
+    DESTINATION ${PYTHON_PACKAGE_DIR}
+    )
+endif(INSTALL_TESTS)

=== modified file 'tests/autopilot/calendar_app/emulators.py'
--- tests/autopilot/calendar_app/emulators.py	2013-11-22 21:22:27 +0000
+++ tests/autopilot/calendar_app/emulators.py	2013-12-16 21:32:43 +0000
@@ -18,19 +18,19 @@
     """
 
     def get_event_view(self):
-        return self.select_single("EventView")
+        return self.wait_select_single("EventView")
 
     def get_month_view(self):
-        return self.select_single("MonthView")
+        return self.wait_select_single("MonthView")
 
     def get_year_view(self):
-        return self.select_single("YearView")
+        return self.wait_select_single("YearView")
 
     def get_day_view(self):
-        return self.select_single("DayView")
+        return self.wait_select_single("DayView")
 
     def get_week_view(self):
-        return self.select_single("WeekView")
+        return self.wait_select_single("WeekView")
 
     def get_label_with_text(self, text, root=None):
         if root is None:
@@ -49,28 +49,28 @@
 
     def get_new_event_name_input_box(self):
         new_event = self.get_new_event()
-        return new_event.select_single("NewEventEntryField",
-                                       objectName="newEventName")
+        return new_event.wait_select_single("NewEventEntryField",
+                                            objectName="newEventName")
 
     def get_event_start_time_field(self):
         new_event = self.get_new_event()
-        return new_event.select_single("NewEventEntryField",
-                                       objectName="startTimeInput")
+        return new_event.wait_select_single("NewEventEntryField",
+                                            objectName="startTimeInput")
 
     def get_event_end_time_field(self):
         new_event = self.get_new_event()
-        return new_event.select_single("NewEventEntryField",
-                                       objectName="endTimeInput")
+        return new_event.wait_select_single("NewEventEntryField",
+                                            objectName="endTimeInput")
 
     def get_event_location_field(self):
         new_event = self.get_new_event()
-        return new_event.select_single("NewEventEntryField",
-                                       objectName="eventLocationInput")
+        return new_event.wait_select_single("NewEventEntryField",
+                                            objectName="eventLocationInput")
 
     def get_event_people_field(self):
         new_event = self.get_new_event()
-        return new_event.select_single("NewEventEntryField",
-                                       objectName="eventPeopleInput")
+        return new_event.wait_select_single("NewEventEntryField",
+                                            objectName="eventPeopleInput")
 
     def get_time_picker(self):
         try:
@@ -78,7 +78,7 @@
         except dbus.StateNotFoundError:
             return None
 
-    def swipe_view(self, direction, view, x_pad=0.35):
+    def swipe_view(self, direction, view, x_pad=0.15):
         """Swipe the given view to left or right.
 
         Args:
@@ -97,9 +97,9 @@
         self.pointing_device.drag(x_start, y_line, x_stop, y_line)
 
     def get_year(self, component):
-        return int(component.select_single(
+        return int(component.wait_select_single(
             "Label", objectName="yearLabel").text)
 
     def get_month_name(self, component):
-        return component.select_single(
+        return component.wait_select_single(
             "Label", objectName="monthLabel").text

=== modified file 'tests/autopilot/calendar_app/tests/__init__.py'
--- tests/autopilot/calendar_app/tests/__init__.py	2013-11-15 16:30:52 +0000
+++ tests/autopilot/calendar_app/tests/__init__.py	2014-01-28 15:31:31 +0000
@@ -62,6 +62,11 @@
             #disabling for now
             #self.addCleanup(os.system("start maliit-server"))
 
+        # Unset the current locale to ensure locale-specific data
+        # (day and month names, first day of the week, …) doesn’t get
+        # in the way of test expectations.
+        self.patch_environment('LC_ALL', 'C')
+
         if os.path.exists(self.local_location):
             self.launch_test_local()
         elif os.path.exists(self.installed_location):
@@ -80,8 +85,6 @@
         self.app = self.launch_test_application(
             "qmlscene",
             self.installed_location,
-            "--desktop_file_hint=/usr/share/applications/"
-            "calendar-app.desktop",
             app_type='qt',
             emulator_base=toolkit_emulators.UbuntuUIToolkitEmulatorBase)
 

=== modified file 'tests/autopilot/calendar_app/tests/test_dayview.py'
--- tests/autopilot/calendar_app/tests/test_dayview.py	2013-11-07 21:01:38 +0000
+++ tests/autopilot/calendar_app/tests/test_dayview.py	2014-01-09 23:30:55 +0000
@@ -75,7 +75,12 @@
         now = datetime.datetime.now()
 
         for i in xrange(1, 5):
-            self.main_view.swipe_view(direction, self.day_view, x_pad=0.15)
+            #prevent timing issues with swiping
+            old_day = self.day_view.currentDay.datetime
+            self.main_view.swipe_view(direction, self.day_view)
+            self.assertThat(lambda: self.day_view.currentDay.datetime,
+                            Eventually(NotEquals(old_day)))
+
             current_day = self.day_view.currentDay.datetime
 
             expected_day = (now + datetime.timedelta(

=== modified file 'tests/autopilot/calendar_app/tests/test_monthview.py'
--- tests/autopilot/calendar_app/tests/test_monthview.py	2013-11-14 20:55:12 +0000
+++ tests/autopilot/calendar_app/tests/test_monthview.py	2014-01-09 23:30:55 +0000
@@ -10,7 +10,7 @@
 from __future__ import absolute_import
 
 from autopilot.matchers import Eventually
-from testtools.matchers import Equals
+from testtools.matchers import Equals, NotEquals
 
 import math
 
@@ -22,31 +22,45 @@
 
 class TestMonthView(CalendarTestCase):
 
-    def get_currentDayStart(self):
-        month_view = self.main_view.get_month_view()
-        return month_view.currentMonth.datetime
+    def setUp(self):
+        super(TestMonthView, self).setUp()
+        self.assertThat(self.main_view.visible, Eventually(Equals(True)))
+        self.main_view.switch_to_tab("monthTab")
+
+        self.assertThat(
+            self.main_view.get_month_view, Eventually(NotEquals(None)))
+
+        self.month_view = self.main_view.get_month_view()
 
     def change_month(self, delta):
         month_view = self.main_view.get_month_view()
         sign = int(math.copysign(1, delta))
 
         for _ in range(abs(delta)):
-            before = self.get_currentDayStart()
+            before = month_view.currentMonth.datetime
+
+            #prevent timing issues with swiping
+            old_month = month_view.currentMonth.datetime
             self.main_view.swipe_view(sign, month_view)
+            self.assertThat(lambda: month_view.currentMonth.datetime,
+                            Eventually(NotEquals(old_month)))
+
             after = before + relativedelta(months=sign)
 
-            self.assertThat(lambda: self.get_currentDayStart().month,
+            self.assertThat(lambda:
+                            self.month_view.currentMonth.datetime.month,
                             Eventually(Equals(after.month)))
-            self.assertThat(lambda: self.get_currentDayStart().year,
+            self.assertThat(lambda:
+                            self.month_view.currentMonth.datetime.year,
                             Eventually(Equals(after.year)))
 
     def _assert_today(self):
         today = datetime.today()
-        self.assertThat(lambda: self.get_currentDayStart().day,
+        self.assertThat(lambda: self.month_view.currentMonth.datetime.day,
                         Eventually(Equals(today.day)))
-        self.assertThat(lambda: self.get_currentDayStart().month,
+        self.assertThat(lambda: self.month_view.currentMonth.datetime.month,
                         Eventually(Equals(today.month)))
-        self.assertThat(lambda: self.get_currentDayStart().year,
+        self.assertThat(lambda: self.month_view.currentMonth.datetime.year,
                         Eventually(Equals(today.year)))
 
     def _test_go_to_today(self, delta):

=== modified file 'tests/autopilot/calendar_app/tests/test_weekview.py'
--- tests/autopilot/calendar_app/tests/test_weekview.py	2014-01-31 01:24:47 +0000
+++ tests/autopilot/calendar_app/tests/test_weekview.py	2014-01-31 01:35:20 +0000
@@ -33,20 +33,20 @@
         self.week_view = self.main_view.get_week_view()
 
     def _change_week(self, direction):
-        #TODO: fix this locale issue. The lab needs a monday start date
-        #http://bugs.python.org/issue17659
-        #weekview has firstDate property we can use instead
-        #uses unix timestamp of first day of current week @ 5 am UTC
-
         first_dow = self._get_first_day_of_week()
 
-        self.main_view.swipe_view(direction, self.week_view, x_pad=0.15)
-        day_start = self.week_view.dayStart.datetime
+        #prevent timing issues with swiping
+        old_day = self.week_view.dayStart.datetime
+        self.main_view.swipe_view(direction, self.week_view)
+        self.assertThat(lambda: self.week_view.dayStart.datetime,
+                        Eventually(NotEquals(old_day)))
+
+        new_day_start = self.week_view.dayStart.datetime
 
         expected_day_start = first_dow + datetime.timedelta(
             days=(7 * direction))
 
-        self.assertThat(day_start.day, Equals(expected_day_start.day))
+        self.assertThat(new_day_start.day, Equals(expected_day_start.day))
 
     def _get_days_of_week(self):
         #sort based on text value of the day
@@ -103,7 +103,7 @@
         #set the start of week
         if date.day != firstDay.day:
             day_start = date - diff
-            logger.debug("Setting day_start %s to " % firstDay.day)
+            logger.debug("Setting day_start to %s" % firstDay.day)
         else:
             day_start = date
             logger.debug("Using today as day_start %s" % date)

=== modified file 'tests/autopilot/calendar_app/tests/test_yearview.py'
--- tests/autopilot/calendar_app/tests/test_yearview.py	2014-01-31 01:26:05 +0000
+++ tests/autopilot/calendar_app/tests/test_yearview.py	2014-01-31 01:35:20 +0000
@@ -104,11 +104,12 @@
         current_year = datetime.now().year
 
         for i in xrange(1, how_many):
-            self.main_view.swipe_view(direction, self.year_view, x_pad=0.15)
-            selected_year = self.year_view.currentYear.year
+            #prevent timing issues with swiping
+            self.main_view.swipe_view(direction, self.year_view)
 
             self.assertThat(
-                selected_year, Equals(current_year + (i * direction)))
+                lambda: self.year_view.currentYear.year,
+                Eventually(Equals(current_year + (i * direction))))
 
     def assert_current_year_is_default_one(self, month_component):
         self.assertThat(self.main_view.get_year(month_component),

=== added file 'tests/unittests/CMakeLists.txt'
--- tests/unittests/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/unittests/CMakeLists.txt	2014-01-28 16:51:15 +0000
@@ -0,0 +1,8 @@
+find_program(QMLTESTRUNNER qmltestrunner)
+
+file(GLOB TESTS tst_*.qml)
+foreach(TEST ${TESTS})
+    get_filename_component(NAME ${TEST} NAME_WE)
+    add_test(${NAME} ${QMLTESTRUNNER} -input ${TEST})
+    set_tests_properties(${NAME} PROPERTIES ENVIRONMENT "QT_QPA_PLATFORM=minimal")
+endforeach(TEST)

